@@ -1,5 +1,5 @@
 # -*- coding: utf-8
-from ..data import BoletoData, CustomProperty
+from ..data import BoletoData, custom_property
 
 
 class BoletoBradesco(BoletoData):
@@ -7,15 +7,16 @@ class BoletoBradesco(BoletoData):
         Gera Dados necessários para criação de boleto para o banco Bradesco
     '''
 
-    nosso_numero = CustomProperty('nosso_numero', 11)
-    agencia_cedente = CustomProperty('agencia_cedente', 4)
-    conta_cedente = CustomProperty('conta_cedente', 7)
+    nosso_numero = custom_property('nosso_numero', 11)
+    agencia_cedente = custom_property('agencia_cedente', 4)
+    conta_cedente = custom_property('conta_cedente', 7)
 
     def __init__(self):
         super(BoletoBradesco, self).__init__()
 
         self.codigo_banco = "237"
         self.logo_image = "logo_bancobradesco.jpg"
+        self.carteira = '06'
 
     def format_nosso_numero(self):
         return "%s/%s-%s" % (
@@ -36,6 +37,10 @@ class BoletoBradesco(BoletoData):
             dv = digito
         return dv
 
+    agencia_cedente = custom_property('agencia_cedente', 4)
+
+    conta_cedente = custom_property('conta_cedente', 7)
+
     @property
     def campo_livre(self):
         content = "%4s%2s%11s%7s%1s" % (self.agencia_cedente.split('-')[0],
