@@ -4,7 +4,7 @@ import datetime
 
 from pyboleto.bank.caixa import BoletoCaixa
 
-from testutils import BoletoTestCase
+from .testutils import BoletoTestCase
 
 
 class TestBancoCaixa(BoletoTestCase):
@@ -21,9 +21,6 @@ class TestBancoCaixa(BoletoTestCase):
         d.numero_documento = '270319510'
         self.dados = d
 
-    def test_render(self):
-        self.check_pdf_rendering('caixa', self.dados)
-
     def test_linha_digitavel(self):
         self.assertEqual(self.dados.linha_digitavel,
             '10498.01952 25086.156582 70000.004146 1 53880000295295'
